from setuptools import setup

setup(name='probability_dstbn',
      version='1.1',
      description='Gaussian and Binomial distribution simplified',
      packages=['probability_dstbn'],
      author= 'Pratik Poudel',
      author_email= 'xpresspratik@gmail.com',
      zip_safe=False)
